==> chromium-51.0.2692.0.tar.xz: chromium-51.0.2692.0/chrome/browser/chromeos/login/ui/login_feedback.h <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_UI_LOGIN_FEEDBACK_H_
#define CHROME_BROWSER_CHROMEOS_LOGIN_UI_LOGIN_FEEDBACK_H_

#include <string>

#include "base/callback.h"
#include "base/macros.h"
#include "base/memory/scoped_ptr.h"
#include "base/memory/weak_ptr.h"

class Profile;

namespace chromeos {

// Show the feedback UI to collect a feedback on the login screen. Note that
// it dynamically loads/unloads the feedback extension on the signin profile,
// there should only be one instance live of this class. Otherwise, they would
// stamp on each other toes and not function properly.
class LoginFeedback {
 public:
  explicit LoginFeedback(Profile* signin_profile);
  ~LoginFeedback();

  // Request to show the feedback UI with |description|. |finished_callback|
  // will be invoked when the feedback UI is closed, either cancel or send the
  // feedback.
  void Request(const std::string& description,
               const base::Closure& finished_callback);

 private:
  // Loads and unloads the feedback extension on the signin profile.
  class ScopedFeedbackExtension;

  // Makes the feedback UI windows on top of login screen and watches when
  // all feedback windows are closed.
  class FeedbackWindowHandler;

  // Invoked by ScopedFeedbackExtension when feedback extension is ready.
  void OnFeedbackExtensionReady();

  // Invoked by FeedbackWindowHandler when all feedback windows are closed.
  void OnFeedbackFinished();

  // Ensures feedback UI is created.
  void EnsureFeedbackUI();

  Profile* const profile_;
  std::string description_;
  base::Closure finished_callback_;

  scoped_ptr<ScopedFeedbackExtension> feedback_extension_;
  scoped_ptr<FeedbackWindowHandler> feedback_window_handler_;

  base::WeakPtrFactory<LoginFeedback> weak_factory_;

  DISALLOW_COPY_AND_ASSIGN(LoginFeedback);
};

}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_LOGIN_UI_LOGIN_FEEDBACK_H_

==> chromium-52.0.2729.3.tar.xz: chromium-52.0.2729.3/chrome/browser/chromeos/login/ui/login_feedback.h <==
// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_LOGIN_UI_LOGIN_FEEDBACK_H_
#define CHROME_BROWSER_CHROMEOS_LOGIN_UI_LOGIN_FEEDBACK_H_

#include <memory>
#include <string>

#include "base/callback.h"
#include "base/macros.h"
#include "base/memory/weak_ptr.h"

class Profile;

namespace chromeos {

// Show the feedback UI to collect a feedback on the login screen. Note that
// it dynamically loads/unloads the feedback extension on the signin profile.
class LoginFeedback {
 public:
  explicit LoginFeedback(Profile* signin_profile);
  ~LoginFeedback();

  // Request to show the feedback UI with |description|. |finished_callback|
  // will be invoked when the feedback UI is closed, either cancel or send the
  // feedback.
  void Request(const std::string& description,
               const base::Closure& finished_callback);

 private:
  // Makes the feedback UI windows on top of login screen and watches when
  // all feedback windows are closed.
  class FeedbackWindowHandler;

  // Invoked by FeedbackWindowHandler when all feedback windows are closed.
  void OnFeedbackFinished();

  // Ensures feedback UI is created.
  void EnsureFeedbackUI();

  Profile* const profile_;
  std::string description_;
  base::Closure finished_callback_;

  std::unique_ptr<FeedbackWindowHandler> feedback_window_handler_;

  base::WeakPtrFactory<LoginFeedback> weak_factory_;

  DISALLOW_COPY_AND_ASSIGN(LoginFeedback);
};

}  // namespace chromeos

#endif  // CHROME_BROWSER_CHROMEOS_LOGIN_UI_LOGIN_FEEDBACK_H_
